<?php
class swProjectClient extends Basic {
    var $table = "project";
    var $className = "swProjectClient";

    function __construct($dbConn) {
        parent::__construct($dbConn);
        $this->table = DB_TABLE_PREFIX.$this->table;
        $this->oUsers = new swProjectUsers($dbConn);
        $this->oKerdezo = new swKerdezo($dbConn);
    }

    function deleteProject($ID=0) {
        $ID = $this->checkID($ID);
        $saveArr = array(
            "disabled" => 1,
            "status" => RES_DELETED
        );
        return $this->Save($saveArr, $ID);
    }

    /*
     * ELlenőrzi, hogy létezik-e a hide_for_client cella az swc_project DB táblában
     * és ha nem, akkor létrehozza
     */
    function checkHideForClientCell() {
        $sqlInfo = $this->DBcon->serverInfo();
        $sqlVersion = $sqlInfo['description'];
        if (strpos($sqlVersion, "Maria---DB")) {
            $sql = "ALTER TABLE `swc_project` ADD COLUMN IF NOT EXISTS `hide_for_client` TINYINT NULL DEFAULT '0' AFTER `disabled`";
            return $this->sqlExe($sql);
        }
        else {
            $sql = "SHOW COLUMNS FROM `swc_project` LIKE 'hide_for_client'";
            $res = $this->sqlExe($sql);
            if ($res->fields['Field'] != 'hide_for_client') {
                $sql = "ALTER TABLE `swc_project` ADD `hide_for_client` TINYINT NULL DEFAULT '0' AFTER `disabled`";
                return $this->sqlExe($sql);
            }
        }
    }

    // ---------------------- TELEPITŐ CSOMAGOK ----------------------
    function getVersionPackageDir($version, $ID=0) {
        if (! $ID = $this->checkID($ID) ) return false;
        $prPackDir = _INSTALL_PACK_DIR ."/".$this->ID;
        if (! file_exists($prPackDir)) { mkdir($prPackDir, 0777, true); }
        if ($version > 0) {
            $prPackVersionDir = $prPackDir."/".$version;
            if (! file_exists($prPackVersionDir)) { mkdir($prPackVersionDir, 0777, true); }
            return $prPackVersionDir;
        } else return $prPackDir;
    }

    function getInstallPackFileURL($version=0, $filename="", $ID=0) {
        $ID = $this->checkID();
        $packDir = $this->getVersionPackageDir($version);
        if (! $filename) $filename = _INSTALL_ZIP_FILE;
        $packURL = $packDir."/".$filename;
        return $packURL;
    }

    function getAbsInstallDir($version=0) {
        $zipFile = _INSTALL_BASE_DIR."/"._BASE_DIR_NAME."/";
        $zipFile .= $this->getVersionPackageDir($version) ;
        return $zipFile;
    }

    function installPackage($version, $ID=0) {
        if (! $ID = $this->checkID()) return false;
        $this->getInfo();
        $old_version = $this->Info['install_pack_version'];
        if ($old_version >= $version) { return false; }
        $fullInstall = ( $this->Info['install_pack_version'] > 0 && $this->Info['status'] == RES_ACTIVE ) ? false : true ;
        $res = array();

        if ($this->zipDownloadPackage($version) ) {
            $res['downloadZIP'] = array("text"=>"Az frissítéshez a ZIP fájl sikeresen letöltődött    : ".$this->getInstallPackFileURL($version));
        } else {  $res['downloadZIP'] =  array("error"=>true, "text"=>"Sikertelen fájl mentés a szerverről: ".$this->getInstallPackFileURL($version)); }

        $res['extractZIP'] = ($this->zipExtractPackage($version) ) ? array("text"=>"Sikeres ZIP fájl kibontás. ".$this->getInstallPackFileURL($version))
            : array("error"=>true, "text"=>"Sikertelen ZIP fájl kibontás: ".$this->getInstallPackFileURL($version)) ;

        $res['extractFilesZIP'] = ($this->extractSurveyFiles($version) ) ? array("text"=>"Sikeres ZIP fájl kibontás: LimeSurvey kutatásokhoz tartozó fájlok mappája")
            : array("error"=>true, "text"=>"Sikeres ZIP fájl kibontás: LimeSurvey kutatásokhoz tartozó fájlok mappája") ;
        $res['importSurveySQL'] = ($this->importLimeSurveysSQL($version) ) ? array("text"=>"Sikeres adatbázis mentés: LimeSurvey kutatás táblák")
            : array("error"=>true, "text"=>"Sikertelen adatbázis mentés: LimeSurvey kutatás táblák") ;

        if ($fullInstall) {
            $res['importCimlistaSQL'] = ($this->importCimlistaSQL($version) ) ? array("text"=>"Sikeres adatbázis mentés: Címlista táblák")
                : array("error"=>true, "text"=>"Sikertelen adatbázis mentés: Címlista táblák") ;
        } else { $res['comment'] = array("error"=>true, "text"=>"A Címlista tábla nem lett installálva, mert a kutatás ezen fázisában ezek a táblák már nem frissíthetőek."); }


        $saveArr = array( "install_pack_version" => $version,
            "last_install" => "NOW()" );
        $this->Save($saveArr);
        return $res;
    }

    // Letölti az install ZIP-et
    function zipDownloadPackage($version) {
        $zipServerAjaxUrl = _SERVER_AJAX_URL ."&cmd=get_install_zip_url&pr_id=".$this->ID;
        if ($zipFileServerURL = url_get_contents($zipServerAjaxUrl)) {
            if ($zipContent = file_get_contents($zipFileServerURL)) {
                $zipDir = $this->getAbsInstallDir($version);
                $zipFile .= $zipDir ."/". _INSTALL_ZIP_FILE;
                return ( file_put_contents($zipFile, $zipContent) );
            } else { echo "Source error: ".$zipFileServerURL; return false; }
        } return false;
    }

    // Kicosmagolja az install ZIP-et
    function zipExtractPackage($version) {
        $zipFile = $this->getInstallPackFileURL($version);
        $zip = new ZipArchive;
        if ($zip->open($zipFile) === TRUE) {
            $zipExtDir = $this->getAbsInstallDir($version);
            if (! $zip->extractTo($zipExtDir)) { echo "Az ".$zipExtDir." hibás lehet."; return false; }
            $zip->close();
        } else {
            echo "A ".$zipFile."nem található."; return false;
        }
        return true;
    }

    // A LimeSurvey kutatáshoz tartozó kérdőíveinek táblastruktúráját importálja
    function importLimeSurveysSQL($version) {
        global $dbConnLS;
        $filename = "limesurvey_surveys.sql";
        $sqlFile = $this->getInstallPackFileURL($version, $filename);

        $templine = '';
        $l = 0;
        $lines = file($sqlFile);
        foreach ($lines as $line) {
            $l++;
            if (substr($line, 0, 2) == '--' || $line == '')  continue;

            $templine .= $line;
            if (substr(trim($line), -1, 1) == ';') {
                if (! (substr(trim($line), -2, 2) == "\;") ) {
                    $templine = stripQuoteSlashes($templine);
                    if (! $dbConnLS->Execute($templine) ) { echo $filename." || Error performing query in line ".$l.": ".$templine." :: ".$dbConnLS->errorMsg(); return false; };
                    $templine = '';
                }
            }
        }
        return true;
    }

    // A kutatáshoz tartozó címlistát importálja
    function importCimlistaSQL($version) {
        global $dbConn;
        $filename = "project_cimlista.sql";
        $sqlFile = $this->getInstallPackFileURL($version, $filename);

        $templine = '';
        $l = 0;
        $lines = file($sqlFile);
        foreach ($lines as $line) {
            $l++;
            if (substr($line, 0, 2) == '--' || $line == '')  continue;
            $templine .= $line;
            if (substr(trim($line), -1, 1) == ';') {
                if (! (substr(trim($line), -2, 2) == "\;") ) {
                    $templine = stripQuoteSlashes($templine);
                    if (! $dbConn->Execute($templine) ) { echo $filename." || Error performing query in line ".$l.": ".$templine." :: ".$dbConn->errorMsg(); return false; };
                    $templine = '';
                }
            }
        }
        return true;
    }

    // A LimeSUrvey kutatáskhoz tartozó külsü fájlokat csomagolja ki
    function extractSurveyFiles($version) {
        $zipExtDir = _INSTALL_BASE_DIR."/"._LS_ZIP_DIR;
        $zipFile = $this->getInstallPackFileURL($version, "project_uploads.zip");

        $zip = new ZipArchive;
        if ($zip->open($zipFile) === TRUE) {
            if (! $zip->extractTo($zipExtDir)) { echo "Az ".$zipExtDir." hibás lehet."; return false; }
            $zip->close();
        } else {
            echo "A ".$zipFile."nem található."; return false;
        }
        return true;
    }

    function saveExportFile($version, $filename, $filecontent) {
        $packDir = $this->getVersionPackageDir($version);
        $file = $packDir."/".$filename;
        $fileHandler = fopen($file, 'w+');
        if (! fwrite($fileHandler, $filecontent)) return false;
        if ( fclose($fileHandler)) return true;
        else return false;
    }


    // ------------- Telepíti a LimeSurvey rendszer alaptábláit ----------------
    function installLimeSystemSQL() {
        if ($this->downloadLimeSystemSQL() ) {  $res['downloadLSsql'] = array("text"=>"A LimeSurvey rendszertáblák frissítéshez az SQL fájl sikeresen letöltődött."); }
        else { $res['downloadLSsql'] =  array("error"=>true, "text"=>"Sikertelen LimeSurvey rendszertáblák SQL fájl mentés a szerverről."); }

        $res['importSystemSQL'] = ($this->importLimeSystemSQL($version) ) ? array("text"=>"Sikeres adatbázis kibontás: LimeSurvey rendszer táblák")
            : array("error"=>true, "text"=>"Sikertelen adatbázis kibontás: LimeSurvey rendszer táblák") ;

        return $res;
    }

    // Letölti a LimeSurvey rendszer alaptábláit
    function downloadLimeSystemSQL() {
        $filename = "limesurvey_system.sql";
        $zipServerAjaxUrl = _SERVER_AJAX_URL ."&cmd=get_install_ls_system_sql_url";
        if ($zipFileServerURL = url_get_contents($zipServerAjaxUrl)) {
            if ($zipContent = file_get_contents($zipFileServerURL)) {
                $zipDir = _INSTALL_BASE_DIR."/"._BASE_DIR_NAME."/"._INSTALL_PACK_DIR;
                $zipFile .= $zipDir ."/". $filename;
                return ( file_put_contents($zipFile, $zipContent) );
            } else { echo "Source error: ".$zipFileServerURL; return false; }
        } return false;
    }

    // A LimeSurvey rendszer alaptábláit importálja
    function importLimeSystemSQL($version) {
        global $dbConnLS;
        $filename = "limesurvey_system.sql";
        $sqlFile = _INSTALL_BASE_DIR."/"._BASE_DIR_NAME."/"._INSTALL_PACK_DIR."/".$filename;

        $templine = '';
        $l = 0;
        $lines = file($sqlFile);
        foreach ($lines as $line) {
            $l++;
            if (substr($line, 0, 2) == '--' || $line == '')  continue;

            $templine .= $line;
            if (substr(trim($line), -1, 1) == ";") {
                if (! (substr(trim($line), -2, 2) == "\;") ) {
                    $templine = stripQuoteSlashes($templine);
                    if (! $dbConnLS->Execute($templine) ) { echo $filename." || Error performing query in line ".$l.": ".$templine." :: ".$dbConnLS->errorMsg(); return false; };
                    $templine = '';
                }
            }
        }
        return true;
    }


    // ----------- Frissíti a kérdezőköd táblát --------------
    function installKerdezoSQL() {
        if ($this->downloadKerdezoSQL() ) {  $res['downloadKerdezoSQL'] = array("text"=>"A kérdezőkód tábla frissítéséhez az SQL fájl sikeresen letöltődött."); }
        else { $res['downloadKerdezoSQL'] =  array("error"=>true, "text"=>"Sikertelen kérdezőkód tábla SQL fájl mentés a szerverről."); }

        $res['importKerdezoSQL'] = ($this->importKerdezoSQL($version) ) ? array("text"=>"Sikeres adatbázis kibontás: Kérdezőkód tábla")
            : array("error"=>true, "text"=>"Sikertelen adatbázis kibontás: Kérdezőkód tábla") ;

        return $res;
    }

    // Letölti a LimeSurvey rendszer alaptábláit
    function downloadKerdezoSQL() {
        $filename = $this->oKerdezo->dumpFile;
        $zipServerAjaxUrl = _SERVER_AJAX_URL ."&cmd=get_install_kerdezo_sql_url";
        if ($zipFileServerURL = url_get_contents($zipServerAjaxUrl)) {
            if ($zipContent = file_get_contents($zipFileServerURL)) {
                $zipDir = _INSTALL_BASE_DIR."/"._BASE_DIR_NAME."/"._INSTALL_PACK_DIR;
                $zipFile .= $zipDir ."/". $filename;
                return ( file_put_contents($zipFile, $zipContent) );
            } else { echo "Source error: ".$zipFileServerURL; return false; }
        } return false;
    }

    // A LimeSurvey rendszer alaptábláit importálja
    function importKerdezoSQL($version) {
        global $dbConn;
        $filename = $this->oKerdezo->dumpFile;
        $sqlFile = _INSTALL_BASE_DIR."/"._BASE_DIR_NAME."/"._INSTALL_PACK_DIR."/".$filename;

        $templine = '';
        $l = 0;
        $lines = file($sqlFile);
        foreach ($lines as $line) {
            $l++;
            if (substr($line, 0, 2) == '--' || $line == '')  continue;

            $templine .= $line;
            if (substr(trim($line), -1, 1) == ";") {
                if (! (substr(trim($line), -2, 2) == "\;") ) {
                    $templine = stripQuoteSlashes($templine);
                    if (! $dbConn->Execute($templine) ) { echo $filename." || Error performing query in line ".$l.": ".$templine." :: ".$dbConn->errorMsg(); return false; };
                    $templine = '';
                }
            }
        }
        return true;
    }


    // ------------------------ CIMLISTA ADATBÁZIS TÁBLÁK ----------------------
    function setUserTables($ID=0) {
        $ID = $this->checkID($ID);
        $this->oUsers->prID = $ID;
        $this->oUsers->setTable($ID);
    }

    function checkUserTables() {
        if (! $this->oUsers->set_tables ) {
            return $this->Error("A swProject class nincs összekapcsolva a Users osztályokkal!!");
        } else return true;
    }

    function emptyUsersTables() {
        if ( $this->checkUserTables() ) {
            return $this->oUsers->emptyTable();
        } else return false;
    }
    
    function dropUsersTables() {
        if ( $this->checkUserTables() ) {
            return $this->oUsers->dropTable();
        } else return false;
    }



    // ------------------ KUTATÁS FOLYAMATA ----------------------
    function getSurveyList($surveyString="") {
        if (! $surveyString) {
            $this->getInfo();
            $surveyString = $this->Info['ls_blocks'];
        }
        $surveyArr = explode(",", $surveyString);
        $surveyArr = array_map('trim', $surveyArr);
        $surveyArr = array_filter($surveyArr, function($value) { settype($value, "integer"); return !is_null($value) && $value > 0; });
        return $surveyArr;
    }

    function loginSurvey($KKOD, $userID, $ID=0) {
        $ID = $this->checkID($ID);
        settype($userID, "integer");
        if (! $ID) return false;
        if (! $userID) return false;

        $this->setUserTables($ID);
        $this->oUsers->ID = $userID;
        if ($this->oUsers->loginSurvey($KKOD, $userID)) {
            $savePrArr = array( "sync" => 1);
            $this->Save($savePrArr);
        }
        return true;
    }

    function startSurvey($userID, $lsID, $ID=0) {
        $ID = $this->checkID($ID);
        settype($userID, "integer");
        settype($ls, "integer");
        if (! $ID) return false;
        if (! $lsID) return false;
        $lsArr = $this->getSurveyList();
        if (! in_array($lsID, $lsArr)) return false;

        return $this->oUsers->startSurvey($lsID, $userID);
    }

    function endSurvey($userID, $lsID, $postArr, $ID=0) {
        $ID = $this->checkID($ID);
        settype($userID, "integer");
        settype($lsID, "integer");
        if (! $ID) return false;
        if (! $lsID) return false;
        $lsArr = $this->getSurveyList();
        if (! in_array($lsID, $lsArr)) return false;

        return $this->oUsers->endSurvey($lsID, $postArr, $userID);
    }

    function logoutSurvey($userID, $ID=0) {
        $ID = $this->checkID($ID);
        settype($userID, "integer");
        if (! $ID) return false;
        if (! $userID) return false;

        $this->setUserTables($ID);
        $this->oUsers->ID = $userID;
        if ($this->oUsers->logoutSurvey($userID)) {
            $savePrArr = array( "sync" => 1);
        }
        return true;
    }



    // ------------------ ADATSZINKRON FOLYAMATA ----------------------
    function getAllSyncTableNames($ID=0) {
        if (! $this->ID = $this->checkID($ID) ) return false;
        $tblNames = array();
        $tblNames[] = "project_".$this->ID."_users_filled";

        $lsList = $this->getSurveyList();
        foreach ($lsList as $lsID) {
            $tblNames[] = "lime_survey_".$lsID;
            $tblNames[] = "lime_survey_".$lsID."_timings";
        }
        return $tblNames;
    }

    function getSyncDir($ID=0) {
        if (! $ID = $this->checkID($ID) ) return false;
        $prPackDir = _SYNC_PACK_DIR ."/".$ID;
        if (! file_exists($prPackDir)) { mkdir($prPackDir, 0777, true); }
        return $prPackDir;
    }

    function getVersionSyncDir($version, $ID=0) {
        if (! $ID = $this->checkID($ID) ) return false;
        $prPackDir = $this->getSyncDir($ID);
        $this->getSoundSyncDir($ID);
        if ($version > 0) {
            $prPackVersionDir = $prPackDir."/".$version;
            if (! file_exists($prPackVersionDir)) { mkdir($prPackVersionDir, 0777, true); }
            return $prPackVersionDir;
        } else return $prPackDir;
    }

    function syncFiles($ID=0) {
        if (! $this->ID = $this->checkID($ID) ) return false;
        $this->setUserTables();
        $this->getInfo();
        $version = $this->Info['sync_pack_version'] + 1;

        if (! $resFiles = $this->genSyncFiles($version) ) return $this->Error("Hiba történt a szinkronizációs fájlok generálása közben!");
        else if (! $this->sendSyncFiles($version) ) return $this->Error("Hiba történt a szerverre történő szinkronizáció közben!");
        else {
            $saveArr = array(   "sync" => 0,
                                "sync_pack_version" => $version,
                                "last_sync" => "NOW()");
            $this->Save($saveArr);
        }
        return $resFiles;
    }

    function genSyncFiles($version) {
        $lsList = $this->getSurveyList();
        foreach ($lsList as $lsID) {
            $table_name = "lime_survey_".$lsID;
            if ($resFile = $this->saveLSTableForSync($table_name, $version)) { $resFiles[] = $resFile; }

            $table_timing_name = "lime_survey_".$lsID."_timings";
            if ($resFile = $this->saveLSTableForSync($table_timing_name, $version)) { $resFiles[] = $resFile; }
        }

        $save_file_dir = $this->getVersionSyncDir($version);
        if ($resFile = $this->oUsers->saveTableForSync($save_file_dir)) { $resFiles[] = $resFile; }

        return $resFiles;
    }

    function sendSyncFiles($version) {
        $curl_url = _SERVER_SYNC_URL;
        $curl_port = 80;
        $curl_useragent = "cURL";
        $postData["id"] = $this->ID;
        $postData["version"] = $version;
        $postData["cimlista_table"] =  "project_".$this->ID."_users_filled";

        $fileDir = $this->getVersionSyncDir($version);
        $tblNames = $this->getAllSyncTableNames();
        foreach ($tblNames as $tblName) {
            $syncFile = $fileDir."/".$tblName.".sql";
            $syncFileContent = file_get_contents($syncFile);
            $postData[$tblName] = $syncFileContent;
        }

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $curl_url); //set the url we want to use
        curl_setopt($ch, CURLOPT_PORT, $curl_port); // set communication port
        curl_setopt($ch, CURLOPT_USERAGENT, $curl_useragent); //set our user agent
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, 1); //set how many paramaters
        curl_setopt($ch, CURLOPT_POSTFIELDS, $postData); //set data to post
        $result= curl_exec ($ch); //execute and get the results
        if (curl_errno($ch)) {
            $result = curl_error($ch);
        }
        curl_close ($ch);
        return $result;
    }

    function saveLSTableForSync($table_name, $version) {
        if (! $table_name ) return $this->Error("saveLSTableToCsv() :: Nincs táblanév megadva");
        $save_file_dir = $this->getVersionSyncDir($version);
        $csvFile = $table_name.".csv";
        $csvFileURL = $save_file_dir ."/". $csvFile;
        $csvContent = "";
        $sqlFile = $table_name.".sql";
        $sqlFileURL = $save_file_dir ."/". $sqlFile;
        $sqlContent = "";

        global $dbConnLS;
        $oLSDB = new Basic($dbConnLS);
        $oLSDB->table = $table_name;

        $sql_num_lines = $oLSDB->getCount();
        if ($sql_num_lines > 0) {
            $oLSDB->DBcon->SetFetchMode(ADODB_FETCH_ASSOC);
            $sqlRes = $oLSDB->sqlExe('SELECT * FROM '.$oLSDB->table." LIMIT 0,1");
            foreach ($sqlRes->fields as $fieldName=>$fieldData) {
                $csvContent .= $fieldName.";";
                $sqlInsertFields .= "`".$fieldName."`,";
            }
            $csvContent = substr($csvContent, 0, -1);
            $csvContent .= "\n";
            $sqlInsertFields = substr($sqlInsertFields, 0, -1);

            $dataRows = $oLSDB->getList();
            foreach ($dataRows as $dID=>$dInfo) {
                $newRowID = (_GEPSZAM * 100000) + $dInfo['id'];

                $sqlInsertDatas = "";
                $sqlUpdateText = "";
                foreach ($dInfo as $cellName=>$cellValue) {
                    $cellValue = preg_replace("/\s+/", ' ', $cellValue);
                    if ($cellName == "id") { $cellValue = $newRowID; }
                    $csvContent .= $cellValue.";";

                    $cellValue = str_replace("'", ' ', $cellValue);
                    $sqlInsertDatas .= "'".$cellValue."',";
                    if ($cellName != "id") { $sqlUpdateText .= "`".$cellName."`='".$cellValue."',"; }
                }
                $csvContent = substr($csvContent, 0, -1);
                $csvContent .= "\n";
                $sqlInsertDatas = substr($sqlInsertDatas, 0, -1);
                $sqlUpdateText = substr($sqlUpdateText, 0, -1);
                $sqlRow = "INSERT INTO `".$oLSDB->table."` (".$sqlInsertFields.") VALUES(".$sqlInsertDatas.") ON DUPLICATE KEY UPDATE ".$sqlUpdateText.";";
                $sqlContent .= $sqlRow."\n";
            }
        }

        // CSV file save
        $fileHandler = fopen($csvFileURL, 'w+');
        if ($sql_num_lines > 0) {
            if (fwrite($fileHandler, $csvContent) === false) return $this->Error("Nem írható ez a fájl: " . $csvFileURL);
        }
        fclose($fileHandler);

        // SQL file save
        $fileHandler = fopen($sqlFileURL, 'w+');
        if ($sql_num_lines > 0) {
            if (fwrite($fileHandler, $sqlContent) === false) return $this->Error("Nem írható ez a fájl: " . $sqlFileURL);
        }
        fclose($fileHandler);

        return $sqlFile;
    }


    // ------------------ HANGFÁJLOK SZINKRON FOLYAMATA ----------------------
    function getSoundSyncDir($ID=0) {
        if (! $ID = $this->checkID($ID) ) return false;
        $prPackDir = $this->getSyncDir($ID);
        $prSoundDir = $prPackDir."/sound";
        if (! file_exists($prSoundDir)) { mkdir($prSoundDir, 0777, true); }
        return $prSoundDir;
    }

    function prepareSyncSoundFiles($ID=0) {
        if (! $this->ID = $this->checkID($ID) ) return false;
        $soundDir = $this->getSoundSyncDir($ID);
        if ($handle = opendir($soundDir)) {
            while (false !== ($filename = readdir($handle))) {
                $filePath = $soundDir."/".$filename;
                if (is_file($filePath)) {
                    if (substr($filename, 0, strlen("error_")) == "error_" ) {
                        $filename = substr($filename, strlen("error_"));
                        rename($filePath, $soundDir."/".$filename);
                    }
                }
            }
            closedir($handle);
        }
        return true;
    }

    function syncSoundFileByOne($ID=0) {
        if (! $this->ID = $this->checkID($ID) ) return false;
        $soundDir = $this->getSoundSyncDir($ID);
        $soundFile = false;
        if ($handle = opendir($soundDir)) {
            while (false !== ($filename = readdir($handle))) {
                $filePath = $soundDir."/".$filename;
                if (is_file($filePath)) {
                    if (substr($filename, 0, strlen("uploaded_")) != "uploaded_" ) {
                        if (substr($filename, 0, strlen("error_")) != "error_" ) {
                            $soundFile = $filename;
                            break;
                        }
                    }
                }
            }
            closedir($handle);
        }
        if ($soundFile) {
            $fileSize = filesize($filePath);
            $fileSize = size_of_file($fileSize);

            $uploadRes = $this->uploadSoundFile($soundFile, $ID);
            $uploadResParts = explode("::", $uploadRes);
            $uploadCommand = $uploadResParts[0];
            $uploadComment = $uploadResParts[1];

            switch ($uploadCommand) {
                case 'error':
                    rename($filePath, $soundDir."/error_".$soundFile);
                    $resultMessage = "HIBA! " . $uploadComment;
                    break;
                case 'success':
                default:
                    rename($filePath, $soundDir."/uploaded_".$soundFile);
                    $resultMessage = "A ".$soundFile." (".$fileSize.") fájl sikeresen feltöltődött a szerverre.";
                    break;
            }

            return $resultMessage;
        }
        else return false;
    }

    function uploadSoundFile( $soundFile, $ID=0 ) {
        if (! $this->ID = $this->checkID($ID) ) return false;

        $curl_url = _SERVER_SOUND_SYNC_URL;
        $curl_port = 80;
        $curl_useragent = "cURL";
        $postData["id"] = $this->ID;
        $postData["file_name"] = $soundFile;

        $soundDir = $this->getSoundSyncDir($ID);
        $filePath = $soundDir."/".$soundFile;
        $syncFileContent = file_get_contents($filePath);
        $postData["file_content"] = $syncFileContent;
        $postData["file_size"] = filesize($filePath);

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $curl_url); //set the url we want to use
        curl_setopt($ch, CURLOPT_PORT, $curl_port); // set communication port
        curl_setopt($ch, CURLOPT_USERAGENT, $curl_useragent); //set our user agent
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, 1); //set how many paramaters
        curl_setopt($ch, CURLOPT_POSTFIELDS, $postData); //set data to post
        $result = curl_exec ($ch); //execute and get the results
        if (curl_errno($ch)) {
            $result = "error::" . curl_error($ch);
        }
        curl_close ($ch);
        return $result;
    }

} // END class

